@@ -16,7 +16,8 @@
 # under the License.
 
 from kudu.client import (Client, Table, Scanner, Session,  # noqa
-                         Insert, Update, Delete, Predicate,
+                         Insert, InsertIgnore, Update, UpdateIgnore,
+                         Delete, DeleteIgnore, Predicate,
                          TimeDelta, KuduError, ScanTokenBuilder,
                          ScanToken,
                          LEADER_ONLY,
@@ -29,7 +30,9 @@ from kudu.client import (Client, Table, Scanner, Session,  # noqa
                          READ_AT_SNAPSHOT,
                          READ_YOUR_WRITES,
                          EXCLUSIVE_BOUND,
-                         INCLUSIVE_BOUND)
+                         INCLUSIVE_BOUND,
+                         CLIENT_SUPPORTS_DECIMAL,
+                         CLIENT_SUPPORTS_PANDAS)
 
 from kudu.errors import (KuduException, KuduBadStatus, KuduNotFound,  # noqa
                          KuduNotSupported,
@@ -37,7 +40,8 @@ from kudu.errors import (KuduException, KuduBadStatus, KuduNotFound,  # noqa
 
 from kudu.schema import (int8, int16, int32, int64, string_ as string,  # noqa
                          double_ as double, float_, float_ as float, binary,
-                         unixtime_micros, bool_ as bool, decimal,
+                         unixtime_micros, bool_ as bool, decimal, varchar,
+                         date,
                          KuduType,
                          SchemaBuilder, ColumnSpec, Schema, ColumnSchema,
                          COMPRESSION_DEFAULT,
